@@ -1,8 +1,8 @@
 /*
  * ark -- archiver for the KDE project
  *
- * Copyright (C) 2008 Harald Hvaal
- * <haraldhv atatatat stud.ntnu.no>
+ * Copyright (C) 2008 Harald Hvaal <haraldhv atatatat stud.ntnu.no>
+ * Copyright (C) 2009 Raphael Kubo da Costa <kubito@gmail.com>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -19,32 +19,39 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  *
  */
+
 #ifndef _ADDDIALOG_H_
 #define _ADDDIALOG_H_
 
 #include "kerfuffle_export.h"
 
+#include <KConfigGroup>
 #include <KFileDialog>
 
 namespace Kerfuffle
 {
+class KERFUFFLE_EXPORT AddDialog : public KFileDialog
+{
+    Q_OBJECT
 
-	class KERFUFFLE_EXPORT AddDialog : public KFileDialog
-	{
-		public:
-			AddDialog(const QStringList& itemsToAdd,
-					const KUrl & 	startDir, 
-					const QString & 	filter, 
-					QWidget * 	parent, 
-					QWidget * 	widget = 0	 
-					);
+public:
+    AddDialog(const QStringList & itemsToAdd,
+              const KUrl & startDir,
+              const QString & filter,
+              QWidget * parent,
+              QWidget * widget = 0
+             );
 
+private:
+    class AddDialogUI *m_ui;
+    KConfigGroup m_config;
 
-		private:
-			class AddDialogUI *m_ui;
-			void setupIconList(const QStringList& itemsToAdd);
-
-	};
+    void loadConfiguration();
+    void setupIconList(const QStringList& itemsToAdd);
 
+private slots:
+    void updateDefaultMimeType();
+};
 }
-#endif 
+
+#endif
