@@ -78,7 +78,7 @@ ParameterList CliPlugin::parameterList() const
     return p;
 }
 
-bool CliPlugin::readListLine(QString line)
+bool CliPlugin::readListLine(const QString &line)
 {
     const QString m_headerString = "-----------------------------------------";
 
@@ -91,6 +91,7 @@ bool CliPlugin::readListLine(QString line)
 
     // catch final line
     if (line.startsWith(m_headerString)) {
+        m_isFirstLine = true;
         m_isInContentListing = false;
         return true;
     }
