@@ -1,5 +1,6 @@
 /*
  * Copyright (c) 2007 Henrique Pinto <henrique.pinto@kdemail.net>
+ * Copyright (c) 2008-2009 Harald Hvaal <haraldhv@stud.ntnu.no>
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions
@@ -27,35 +28,36 @@
 #define LIBARCHIVEHANDLER_H
 
 #include "kerfuffle/archiveinterface.h"
+#include <QList>
+#include <QStringList>
 
 using namespace Kerfuffle;
 
 class LibArchiveInterface: public ReadWriteArchiveInterface
 {
-	Q_OBJECT
-	public:
-		explicit LibArchiveInterface( const QString & filename, QObject *parent = 0 );
-		~LibArchiveInterface();
+    Q_OBJECT
 
-		bool list();
-		bool copyFiles( const QList<QVariant> & files, const QString & destinationDirectory, ExtractionOptions options );
+public:
+    explicit LibArchiveInterface(const QString & filename, QObject *parent = 0);
+    ~LibArchiveInterface();
 
-		bool addFiles( const QStringList & files, const CompressionOptions& options );
-		bool deleteFiles( const QList<QVariant> & files );
+    bool list();
+    bool copyFiles(const QList<QVariant> & files, const QString & destinationDirectory, ExtractionOptions options);
+    bool addFiles(const QStringList & files, const CompressionOptions& options);
+    bool deleteFiles(const QList<QVariant> & files);
 
-	private:
-		int extractionFlags() const;
-		void copyData( struct archive *source, struct archive *dest, bool partialprogress = true );
-		void copyData( QString filename, struct archive *dest, bool partialprogress = true );
-		void emitEntryFromArchiveEntry(struct archive_entry *entry);
-		bool writeFile(const QString& fileName, struct archive* arch, struct archive_entry* entry);
+private:
+    void emitEntryFromArchiveEntry(struct archive_entry *entry);
+    int extractionFlags() const;
+    void copyData(const QString& filename, struct archive *dest, bool partialprogress = true);
+    void copyData(struct archive *source, struct archive *dest, bool partialprogress = true);
+    bool writeFile(const QString& fileName, struct archive* arch, struct archive_entry* entry);
 
-
-		int cachedArchiveEntryCount;
-		qlonglong extractedFilesSize;
-		qlonglong currentExtractedFilesSize;
-		bool m_emitNoEntries;
-		QStringList m_writtenFiles;
+    int m_cachedArchiveEntryCount;
+    qlonglong m_currentExtractedFilesSize;
+    bool m_emitNoEntries;
+    qlonglong m_extractedFilesSize;
+    QStringList m_writtenFiles;
 };
 
 #endif // LIBARCHIVEHANDLER_H
