@@ -3,6 +3,7 @@
     Qt widget libraries, available at no cost at http://www.troll.no
 
     Copyright (C) 2004 Klaus Niederkruger
+                       kniederk@ulb.ac.be
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -23,33 +24,41 @@
 #ifndef _KCALC_CONST_MENU_H
 #define _KCALC_CONST_MENU_H
 
-#include <qpopupmenu.h>
-#include <qstring.h>
+#include <QList>
+#include <QMenu>
+
 
 enum ConstantCategory {Mathematics = 1, Electromagnetic = 2, Nuclear = 4, Thermodynamics = 8, Gravitation = 16};
 
 struct science_constant{
   QString label;
-  const char * name;
+  QString name;
   QString whatsthis;
   QString value;
   ConstantCategory category;
 };
 
-class KCalcConstMenu : public QPopupMenu
+class KCalcConstMenu : public QMenu
 {
 Q_OBJECT 
 
  public:
-  KCalcConstMenu(QWidget * parent = 0, const char * name = 0);
+  KCalcConstMenu(QWidget * parent = 0);
+  explicit KCalcConstMenu(QString const & title, QWidget * parent = 0);
+
+  static QList<struct science_constant> Constants;
+  static void init_consts(void);
+
+signals:
+  void triggeredConstant(struct science_constant const &);
+
+
+ private:
+  void _init_all(void);
 
-  static const struct science_constant Constants[];
 
 public slots:
-  void slotPassActivate(int item)
-  {
-    emit activated(item);
-  };
+  void slotPassSignalThrough(QAction  *chosen_const);
 };
 
 #endif  // _KCALC_CONST_MENU_H
