@@ -18,10 +18,10 @@
    Boston, MA 02110-1301, USA.
 */
 
-#include <math.h>
-
 #include "knumber.h"
 #include "knumber_priv.h"
+#include "kdemacros.h"
+#include "kglobal.h"
 
 #include <cmath>
 #include <cstdio>
@@ -30,20 +30,12 @@
 
 #include <QRegExp>
 
-
 using namespace std;
 
 KNumber const KNumber::Zero(0);
 KNumber const KNumber::One(1);
 KNumber const KNumber::MinusOne(-1);
-KNumber const KNumber::Pi("3.141592653589793238462643383279502884197169"
-			  "39937510582097494459230781640628620899862803"
-			  "4825342117068");
-KNumber const KNumber::Euler("2.718281828459045235360287471352662497757"
-			     "24709369995957496696762772407663035354759"
-			     "4571382178525166427");
 KNumber const KNumber::NotDefined("nan");
-
 bool KNumber::_float_output = false;
 bool KNumber::_fraction_input = false;
 bool KNumber::_splitoffinteger_output = false;
@@ -52,8 +44,6 @@ bool KNumber::_splitoffinteger_output = false;
 
 #ifdef HAVE_IEEEFP_H
 #include <ieeefp.h>
-#else
-#include <math.h>
 #endif
 
 #define isinf(x) (!finite(x) && x == x)
@@ -355,7 +345,7 @@ static QString roundNumber(const QString &numStr, int precision)
   QString expString = tmpString.section('e', 1, 1,
 					QString::SectionCaseInsensitiveSeps |
 					QString::SectionIncludeLeadingSep);
-  if (expString.length() == 1) expString = QString();
+  if (expString.length() == 1) expString.clear();
 
 
   _round(mantString, precision);
@@ -708,3 +698,22 @@ int KNumber::compare(KNumber const & arg2) const
 {
   return _num->compare(*arg2._num);
 }
+
+K_GLOBAL_STATIC_WITH_ARGS(KNumber, g_Pi, (
+"3.141592653589793238462643383279502884197169"
+"39937510582097494459230781640628620899862803"
+"4825342117068") )
+KNumber KNumber::Pi()
+{
+  return *g_Pi;
+}
+
+K_GLOBAL_STATIC_WITH_ARGS(KNumber, g_Euler, (
+"2.718281828459045235360287471352662497757"
+"24709369995957496696762772407663035354759"
+"4571382178525166427") )
+KNumber KNumber::Euler()
+{
+  return *g_Euler;
+}
+
