@@ -1,6 +1,6 @@
 /* vi: ts=8 sts=4 sw=4
  *
- * $Id: sshdlg.cpp 720102 2007-10-02 12:06:26Z ogoffart $
+ * $Id: sshdlg.cpp 984649 2009-06-21 10:29:31Z mlaurent $
  *
  * This file is part of the KDE project, module kdesu.
  * Copyright (C) 2000 Geert Jansen <jansen@kde.org>
@@ -49,7 +49,7 @@ KDEsshDialog::KDEsshDialog(const QString &host, const QString &user, const QStri
     // Make the prompt a little more polite :-)
     if (prompt.toLower().left(6) == QString::fromLatin1("enter "))
         prompt.remove(0, 6);
-    int pos = prompt.indexOf(':');
+    const int pos = prompt.indexOf(':');
     if (pos != -1)
         prompt.remove(pos, 10);
     prompt += '.';
@@ -69,7 +69,7 @@ bool KDEsshDialog::checkPassword(const char *password)
     SshProcess proc(m_Host, m_User);
     proc.setStub(m_Stub);
 
-    int ret = proc.checkInstall(password);
+    const int ret = proc.checkInstall(password);
     switch (ret)
     {
     case -1:
