@@ -451,6 +451,8 @@ KeysManager::KeysManager(QWidget *parent)
 	action->setShortcut(QKeySequence(Qt::Key_F6));
 	connect(m_listviewsearch, SIGNAL(textChanged(const QString &)), iproxy, SLOT(setFilterFixedString(const QString &)));
 
+	setActionDescriptions(1);
+
 	// get all keys data
 	setupGUI(KXmlGuiWindow::Create | Save | ToolBar | StatusBar | Keys, "keysmanager.rc");
 
@@ -971,8 +973,10 @@ void KeysManager::slotDelPhotoFinished(int res)
 
 	// TODO : add res == 3 (bad passphrase)
 
-	if (res == 0)
-		slotUpdatePhoto();
+	if (res == 0) {
+		KGpgNode *nd = iview->selectedNode();
+		imodel->refreshKey(nd->getParentKeyNode()->toKeyNode());
+	}
 }
 
 void KeysManager::slotUpdatePhoto()
@@ -1298,6 +1302,17 @@ void KeysManager::slotSetDefaultKey(const QString &newID)
 	imodel->setDefaultKey(newID);
 }
 
+void
+KeysManager::setActionDescriptions(int cnt)
+{
+	signUid->setText(i18np("&Sign User ID ...", "&Sign User IDs ...", cnt));
+	exportPublicKey->setText(i18np("E&xport Public Key...", "E&xport Public Keys...", cnt));
+	refreshKey->setText(i18np("&Refresh Key From Keyserver", "&Refresh Keys From Keyserver", cnt));
+	createGroup->setText(i18np("&Create Group with Selected Key...", "&Create Group with Selected Keys...", cnt));
+	signKey->setText(i18np("&Sign Key...", "&Sign Keys...", cnt));
+	delUid->setText(i18np("&Delete User ID", "&Delete User IDs", cnt));
+}
+
 void
 KeysManager::slotMenu(const QPoint &pos)
 {
@@ -1330,12 +1345,7 @@ KeysManager::slotMenu(const QPoint &pos)
 	importAllSignKeys->setEnabled(unksig && m_online);
 
 	signUid->setEnabled(!(itype & ~(ITYPE_PAIR | ITYPE_UID | ITYPE_UAT)));
-	signUid->setText(i18np("&Sign User ID ...", "&Sign User IDs ...", cnt));
-	exportPublicKey->setText(i18np("E&xport Public Key...", "E&xport Public Keys...", cnt));
-	refreshKey->setText(i18np("&Refresh Key From Keyserver", "&Refresh Keys From Keyserver", cnt));
-	createGroup->setText(i18np("&Create Group with Selected Key...", "&Create Group with Selected Keys...", cnt));
-	signKey->setText(i18np("&Sign Key...", "&Sign Keys...", cnt));
-	delUid->setText(i18np("&Delete User ID", "&Delete User IDs", cnt));
+	setActionDescriptions(cnt);
 
 	if (itype == ITYPE_SIGN) {
 		bool allunksig = true;
