@@ -1,5 +1,5 @@
 /**
- * Copyright (C) 2008 Rolf Eike Beer <kde@opensource.sf-tec.de>
+ * Copyright (C) 2008,2009 Rolf Eike Beer <kde@opensource.sf-tec.de>
  */
 
 /***************************************************************************
@@ -26,7 +26,7 @@ KGpgDelUid::~KGpgDelUid()
 bool
 KGpgDelUid::nextLine(const QString &line)
 {
-	if (line.startsWith("[GNUPG:] keyedit.remove.uid.okay")) {
+	if (line.contains("keyedit.remove.uid.okay")) {
 		write("YES");
 	} else {
 		return standardCommands(line);
