@@ -1,7 +1,7 @@
 /*
     This file is part of the Okteta Kakao module, part of the KDE project.
 
-    Copyright 2008 Friedrich W. H. Kossebau <kossebau@kde.org>
+    Copyright 2008-2009 Friedrich W. H. Kossebau <kossebau@kde.org>
 
     This library is free software; you can redistribute it and/or
     modify it under the terms of the GNU Lesser General Public
@@ -27,7 +27,6 @@
 #include "statistictablemodel.h"
 // KDE
 #include <KPushButton>
-#include <KDialog>
 #include <KGuiItem>
 #include <KLocale>
 #include <KGlobal>
@@ -45,21 +44,17 @@ InfoView::InfoView( InfoTool *tool, QWidget *parent )
 {
     QVBoxLayout *baseLayout = new QVBoxLayout( this );
     baseLayout->setMargin( 0 );
-    baseLayout->setSpacing( KDialog::spacingHint() );
 
     QHBoxLayout *updateLayout = new QHBoxLayout();
 
-    mDirtyLabel = new QLabel( this );
-    updateLayout->addWidget( mDirtyLabel );
-    connect( mTool, SIGNAL(statisticDirty( bool )), SLOT(setDirty( bool )) );
     updateLayout->addStretch();
 
     const KGuiItem updateGuiItem(
         i18nc("@action:button update the statistic of the byte frequency","&Update"),
         "view-refresh",
-        i18nc("@info:tooltip","Updates the statistic of the byte frequency."),
+        i18nc("@info:tooltip","Updates the byte frequency statistics."),
         i18nc("@info:whatsthis",
-              "If you press the <interface>Update</interface> button, the statistic of the byte frequency is updated.") );
+              "If you press the <interface>Update</interface> button, the byte frequency statistics are updated.") );
     mUpdateButton = new KPushButton( updateGuiItem, this );
     mUpdateButton->setEnabled( mTool->isApplyable() );
     connect( mTool, SIGNAL(isApplyableChanged(bool)), mUpdateButton, SLOT( setEnabled(bool )) );
@@ -70,7 +65,7 @@ InfoView::InfoView( InfoTool *tool, QWidget *parent )
 
     QHBoxLayout *sizeLayout = new QHBoxLayout();
 
-    QLabel *label = new QLabel( i18nc("@label","Size [bytes]: "), this );
+    QLabel *label = new QLabel( i18nc("@label size of selected bytes","Size:"), this );
     sizeLayout->addWidget( label );
 
     mSizeLabel = new QLabel( this );
@@ -86,14 +81,15 @@ InfoView::InfoView( InfoTool *tool, QWidget *parent )
     mStatisticTableView->setAllColumnsShowFocus( true );
     mStatisticTableView->setSortingEnabled( true );
     mStatisticTableView->setFont( KGlobalSettings::fixedFont() );
-    mStatisticTableView->header()->setFont( font() );
+    QHeaderView* header = mStatisticTableView->header();
+    header->setFont( font() );
+    header->setResizeMode( QHeaderView::ResizeToContents );
+    header->setStretchLastSection( false );
     // TODO: write subclass to filter count and percent by num, not string
     QSortFilterProxyModel *proxyModel = new QSortFilterProxyModel( this );
     proxyModel->setDynamicSortFilter( true );
     proxyModel->setSourceModel( mTool->statisticTableModel() );
     mStatisticTableView->setModel( proxyModel );
-    for( int c = 0; c<StatisticTableModel::NoOfIds; ++c )
-        mStatisticTableView->resizeColumnToContents( c );
     mStatisticTableView->sortByColumn( StatisticTableModel::CountId, Qt::DescendingOrder );
     connect( mTool->statisticTableModel(), SIGNAL(headerChanged()), SLOT(updateHeader()) );
 
@@ -111,16 +107,11 @@ void InfoView::updateHeader()
 
 void InfoView::setByteArraySize( int size )
 {
-    const QString sizeText = ( size == -1 ) ?
+    const QString sizeText = ( size < 1 ) ? // -1 is default, 0 should not happen
         QString( '-' ) :
-        KGlobal::locale()->formatNumber( size, 0 );
+        i18np( "1 byte", "%1 bytes", size );
+
     mSizeLabel->setText( sizeText );
 }
 
-void InfoView::setDirty( bool dirty )
-{
-    mDirtyLabel->setText( dirty ? i18nc("@info:status the statistic is not uptodate","Warning: not uptodate") : QString() );
-    mDirtyLabel->setToolTip( dirty ? i18nc("@info:tooltip","Warning: Byte Array has been modified since last update.") : QString() );
-}
-
 InfoView::~InfoView() {}
